# hfcldd.spec - hfcldd package for Driver Update Model
#
# Copyright (C) 2009, Hitachi, Ltd.
#
# Based on test.spec by Jon Masters <jcm@redhat.com>
# at http://www.kerneldrivers.org/RedHatKernelModulePackages

# kversion: target kernel version as 'uname -r', e.g., 2.6.18-8.el5xen.
%{!?kversion: %define kversion %(uname -r)}

# kverrel: kversion where variant suffix (xen and PAE) is removed.
%{expand:%define kverrel %( shopt -s extglob; foo=%{kversion}; echo ${foo%%%%@(xen|PAE)} )}

# kvariant: variant suffix itself.  Can be an empty string.
%{expand:%define kvariant %( foo=%{kversion}; echo ${foo#%{kverrel}} )}

# kvar: yields '-' plus kvariant if kvariant is non-null.  Null otherwise.
%{expand:%define kvar %( _kv=%{kvariant}; echo -n ${_kv:+-$_kv} )}

# kdevel: name of matching kernel-devel package.
%{expand:%define kdevel kernel%{kvar}-devel-%{_target_cpu}}

# ksrc: kernel source directory, provided by matching kernel-devel package.
%{expand:%define ksrc %{_usrsrc}/kernels/%{kverrel}%{kvar}-%{_target_cpu}}

ExclusiveArch: i686 x86_64 ia64

Name:       hfcldd%{kvar}
%ifarch ia64
Version: 1.5.14.1038
%else
%ifarch x86_64
Version: 1.5.14.1038
%else
Version: 1.5.14.1038
%endif
%endif
Release:    1.%(echo %{kverrel} | tr - _)
Summary:    Hitachi Fibre Channel Host Bus Adapter Driver
License:    GPL
Group:      System Environment/Drivers
Source0:    hfcldd.tar.gz
BuildRoot:  %{_tmppath}/%{name}-%{version}-root

%global _use_internal_dependency_generator 0

Provides:   kernel-modules = %{kversion}
Provides:   %{name} = %{version}-%{release}
Requires(post): /sbin/depmod, /usr/bin/printf
Requires(postun): /sbin/depmod, /usr/bin/printf
BuildRequires: %{kdevel} = %{kverrel}

%description 
A hfcldd package for Driver Update Model.

%prep
[ "$RPM_BUILD_ROOT" != "/" ] && rm -rf $RPM_BUILD_ROOT
rm -rf $RPM_BUILD_ROOT/opt/hitachi/drivers/hba
mkdir -p $RPM_BUILD_ROOT/opt/hitachi/drivers/hba

%setup -n hfcldd-%{version}

%build
make -C "%{ksrc}" M=$PWD V=1 modules 
make -C "%{ksrc}" M=$PWD/../hfcldd-conf-%{version} V=1 modules 
make -C "%{ksrc}" M=$PWD/../hfcldd-link-%{version} V=1 modules 


%install
make -C "%{ksrc}" M=$PWD V=1 modules_install INSTALL_MOD_PATH=$RPM_BUILD_ROOT INSTALL_MOD_DIR=extra/hitachi/hfcldd
make -C "%{ksrc}" M=$PWD/../hfcldd-conf-%{version} V=1 modules_install INSTALL_MOD_PATH=$RPM_BUILD_ROOT INSTALL_MOD_DIR=extra/hitachi/hfcldd
make -C "%{ksrc}" M=$PWD/../hfcldd-link-%{version} V=1 modules_install INSTALL_MOD_PATH=$RPM_BUILD_ROOT INSTALL_MOD_DIR=extra/hitachi/hfcldd
install -d -o root -g root $RPM_BUILD_ROOT/opt/hitachi/drivers/hba
install -o root -g root hfcinst.el5.sh $RPM_BUILD_ROOT/opt/hitachi/drivers/hba
install -o root -g root COPYING $RPM_BUILD_ROOT/opt/hitachi/drivers/hba
install -o root -g root version_hfcldd.txt $RPM_BUILD_ROOT/opt/hitachi/drivers/hba


# In post, it is better to list modules explicitly.
%post
if [ "%{kvariant}" = "PAE" ]; then 
	/opt/hitachi/drivers/hba/hfcinst.el5.sh install PAE
else
	/opt/hitachi/drivers/hba/hfcinst.el5.sh install
fi

if [ -e /boot/System.map-%{kversion} ]; then
    /sbin/depmod -aeF /boot/System.map-%{kversion} %{kversion} > /dev/null || :
fi

if [ -f /lib/modules/%{kversion}/extra/hitachi/hfcldd/hraslog_link.ko.hraslog.rename ]; then
	if [ -x /sbin/weak-modules ]; then
		cat <<EOF | /sbin/weak-modules --no-initrd --add-modules
/lib/modules/%{kversion}/extra/hitachi/hfcldd/hraslog_link.ko
/lib/modules/%{kversion}/extra/hitachi/hfcldd/hfcldd.ko
/lib/modules/%{kversion}/extra/hitachi/hfcldd/hfcldd_conf.ko
EOF
	fi
	rm /lib/modules/%{kversion}/extra/hitachi/hfcldd/hraslog_link.ko
	if [ -x /sbin/weak-modules ]; then
		cat <<EOF | /sbin/weak-modules --remove-modules
/lib/modules/%{kversion}/extra/hitachi/hfcldd/hraslog_link.ko
EOF
	fi
else
	if [ -x /sbin/weak-modules ]; then
		cat <<EOF | /sbin/weak-modules --add-modules
/lib/modules/%{kversion}/extra/hitachi/hfcldd/hraslog_link.ko
/lib/modules/%{kversion}/extra/hitachi/hfcldd/hfcldd.ko
/lib/modules/%{kversion}/extra/hitachi/hfcldd/hfcldd_conf.ko
EOF
	fi
fi

# In preun, it is better to list modules explicitly.
%preun
if [ "%{kvariant}" = "PAE" ]; then 
	/opt/hitachi/drivers/hba/hfcinst.el5.sh uninstall PAE
else
	/opt/hitachi/drivers/hba/hfcinst.el5.sh uninstall
fi

# In postun, it is better to list modules explicitly.
%postun
/sbin/depmod -aF /boot/System.map-%{kversion} %{kversion} &> /dev/null || :
if [ -x /sbin/weak-modules ]; then
    cat <<EOF | /sbin/weak-modules --remove-modules
/lib/modules/%{kversion}/extra/hitachi/hfcldd/hraslog_link.ko
/lib/modules/%{kversion}/extra/hitachi/hfcldd/hfcldd.ko
/lib/modules/%{kversion}/extra/hitachi/hfcldd/hfcldd_conf.ko
EOF
fi

# In files, do not list directories if not yours.
%files
%defattr(644,root,root,755)
/lib/modules/%{kversion}/extra/hitachi/hfcldd/hraslog_link.ko
/lib/modules/%{kversion}/extra/hitachi/hfcldd/hfcldd.ko
/lib/modules/%{kversion}/extra/hitachi/hfcldd/hfcldd_conf.ko
%dir /lib/modules/%{kversion}/extra/hitachi/hfcldd
%defattr(755,root,root,755)
/opt/hitachi/drivers/hba/*

%clean
rm -rf $RPM_BUILD_ROOT

%changelog
* Mon Sep 14 2009 Tetsuhiro Goto <tetsuhiro.goto.ca@hitachi.com>
- Revision 1.5.14.1038 support
